==> firebase_document_repository-0.0.3.tar.gz: lib/core/dynamic_uri_repository.dart <==

import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:firebase_document_repository/core/identifiable.dart';
import 'package:rxdart/rxdart.dart';

typedef AsyncCollectionProvider = Future<CollectionReference> Function();

abstract class DynamicUriRepository<Value extends Identifiable> {
  AsyncCollectionProvider collection;
  BehaviorSubject<List<Value>> itemsController =
  BehaviorSubject<List<Value>>.seeded(<Value>[]);
  Stream<List<Value>> get items => itemsController.stream;

  DynamicUriRepository(this.collection) {
    initItems();
  }

  Value fromMap(Map data);
  Map toMap(Value value);

  List<Value> snapshotToValues(QuerySnapshot snapshot) {
    return snapshot.documents.map<Value>((doc) => fromMap(doc.data)).toList();
  }

  void initItems() async {
    var valueList = await list();
    itemsController.add(valueList);
    itemsController
        .addStream(( await collection()).snapshots().map<List<Value>>(snapshotToValues));
  }


  Future<Value> get(dynamic id) async{
    var data = (await (await collection()).document(id).get()).data;
    if(data == null){
      return null;
    }
    else{
      return fromMap(data);
    }
  }


  Future<Value> add(Value t) async {
    var doc = (await collection()).document();
    t.id = doc.documentID;
    Map<String, dynamic> json = toMap(t);
    await doc.setData(json);
    return t;
  }


  Future<List<Value>> list() async {
    var documents = await listDocuments();
    var data = documents.map<Value>((d) => fromMap(d.data)).toList();
    return data;
  }

  Future<List<DocumentSnapshot>> listDocuments() async {
    QuerySnapshot result = await (await collection()).getDocuments();
    return result.documents;
  }


  Future<bool> remove(Value t) async {
    await (await collection()).document(t.id).delete();
  }
}

==> firebase_document_repository-0.0.4.tar.gz: lib/core/dynamic_uri_repository.dart <==

import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:firebase_document_repository/core/identifiable.dart';
import 'package:rxdart/rxdart.dart';

typedef AsyncCollectionProvider = Future<CollectionReference> Function();

abstract class DynamicUriRepository<Value extends Identifiable> {
  AsyncCollectionProvider collection;
  BehaviorSubject<List<Value>> itemsController =
  BehaviorSubject<List<Value>>.seeded(null);
  Stream<List<Value>> get items => itemsController.stream;

  DynamicUriRepository(this.collection) {
    initItems();
  }

  Value fromMap(Map data);
  Map toMap(Value value);

  List<Value> snapshotToValues(QuerySnapshot snapshot) {
    return snapshot.documents.map<Value>((doc) => fromMap(doc.data)).toList();
  }

  void initItems() async {
    var valueList = await list();
    itemsController.add(valueList);
    itemsController
        .addStream(( await collection()).snapshots().map<List<Value>>(snapshotToValues));
  }


  Future<Value> update(Value t) async{
    var doc = (await collection()).document(t.id);
    var result = await doc.updateData(toMap(t));
    return t;
  }

  Future<Value> get(dynamic id) async{
    var data = (await (await collection()).document(id).get()).data;
    if(data == null){
      return null;
    }
    else{
      return fromMap(data);
    }
  }


  Future<Value> add(Value t) async {
    var doc = (await collection()).document();
    t.id = doc.documentID;
    Map<String, dynamic> json = toMap(t);
    await doc.setData(json);
    return t;
  }


  Future<List<Value>> list() async {
    var documents = await listDocuments();
    var data = documents.map<Value>((d) => fromMap(d.data)).toList();
    return data;
  }

  Future<List<DocumentSnapshot>> listDocuments() async {
    QuerySnapshot result = await (await collection()).getDocuments();
    return result.documents;
  }


  Future<bool> remove(Value t) async {
    await (await collection()).document(t.id).delete();
  }
}
